@@ -5,7 +5,7 @@
 
 #import <Foundation/Foundation.h>
 
-#import "RCTBridgeModule.h"
+#import "React/RCTBridgeModule.h"
 
 @interface RCT_EXTERN_MODULE(RNVideoTrimmer, NSObject)
 
