@@ -14,7 +14,8 @@ export class Trimmer extends Component {
     minLength: PropTypes.number,
     maxLength: PropTypes.number,
     currentTime: PropTypes.number,
-    trackerColor: PropTypes.string
+    trackerColor: PropTypes.string,
+    thumbWidth: PropTypes.number
   };
 
   static defaultProps = {
@@ -53,7 +54,8 @@ export class Trimmer extends Component {
       minLength,
       maxLength,
       currentTime,
-      trackerColor
+      trackerColor,
+      thumbWidth,
     } = this.props;
     const actualSource = getActualSource(source);
     return (
@@ -69,6 +71,7 @@ export class Trimmer extends Component {
         onChange={this._onChange}
         minLength={minLength}
         maxLength={maxLength}
+        thumbWidth={thumbWidth}
       />
     );
   }
